@@ -33,36 +33,36 @@ logger = logging.getLogger(__name__)
 
 def _get_parser():
     parser = argparse.ArgumentParser(
-        description="GitLabracadabra")
-    parser.add_argument("--version", help="Display the version.",
-                        action="store_true")
-    parser.add_argument("-v", "--verbose", "--fancy",
-                        help="Verbose mode",
-                        action="store_true")
-    parser.add_argument("-d", "--debug",
-                        help="Debug mode (display HTTP requests)",
-                        action="store_true")
-    parser.add_argument("-c", "--config-file", action='append',
-                        help=("Configuration file to use. Can be used "
-                              "multiple times."))
-    parser.add_argument("-g", "--gitlab",
-                        help=("Which configuration section should "
-                              "be used. If not defined, the default selection "
-                              "will be used."),
+        description='GitLabracadabra')
+    parser.add_argument('--version', help='Display the version.',
+                        action='store_true')
+    parser.add_argument('-v', '--verbose', '--fancy',
+                        help='Verbose mode',
+                        action='store_true')
+    parser.add_argument('-d', '--debug',
+                        help='Debug mode (display HTTP requests)',
+                        action='store_true')
+    parser.add_argument('-c', '--config-file', action='append',
+                        help=('Configuration file to use. Can be used '
+                              'multiple times.'))
+    parser.add_argument('-g', '--gitlab',
+                        help=('Which configuration section should '
+                              'be used. If not defined, the default selection '
+                              'will be used.'),
                         required=False)
-    parser.add_argument("--dry-run",
-                        help="Dry run",
-                        action="store_true")
-    parser.add_argument("--doc-markdown",
-                        help=("Output the help for the given type (project, "
-                              "group, user, application_settings) as "
-                              "Markdown."))
-    parser.add_argument("action_files",
-                        help="Action file. Can be used "
-                              "multiple times.",
-                        metavar="ACTIONFILE.yml",
+    parser.add_argument('--dry-run',
+                        help='Dry run',
+                        action='store_true')
+    parser.add_argument('--doc-markdown',
+                        help=('Output the help for the given type (project, '
+                              'group, user, application_settings) as '
+                              'Markdown.'))
+    parser.add_argument('action_files',
+                        help='Action file. Can be used '
+                              'multiple times.',
+                        metavar='ACTIONFILE.yml',
                         nargs='*',
-                        default=["gitlabracadabra.yml"])
+                        default=['gitlabracadabra.yml'])
 
     return parser
 
@@ -106,15 +106,15 @@ def main():
         if action_file.endswith('.yml') or action_file.endswith('.yaml'):
             parser = gitlabracadabra.parser.GitlabracadabraParser.from_yaml_file(action_file)
         else:
-            logger.error("Unhandled file: %s", action_file)
+            logger.error('Unhandled file: %s', action_file)
             has_errors = True
             continue
-        logger.debug("Parsing file: %s", action_file)
+        logger.debug('Parsing file: %s', action_file)
         objects[action_file] = parser.objects()
         for k, v in sorted(objects[action_file].items()):
             if len(v.errors()) > 0:
                 for e in v.errors():
-                    logger.error("Error in %s::: %s", k, e.message)
+                    logger.error('Error in %s::: %s', k, e.message)
                 has_errors = True
 
     if has_errors:
@@ -123,5 +123,9 @@ def main():
 
     # Second pass:
     for action_file in args.action_files:
-        for name, obj in sorted(objects[action_file].items()):
+        for _name, obj in sorted(objects[action_file].items()):
             obj.process(args.dry_run)
+
+
+if __name__ == '__main__':
+    main()
