@@ -31,13 +31,13 @@ logger = logging.getLogger(__name__)
 
 class GitLabracadabraObject(object):
     SCHEMA = {
-        "$schema": "http://json-schema.org/draft-04/schema#",
-        "title": "Object",
-        "type": "object",
-        "properties": {
+        '$schema': 'http://json-schema.org/draft-04/schema#',
+        'title': 'Object',
+        'type': 'object',
+        'properties': {
         },
-        "additionalProperties": False,
-        # "required": [],
+        'additionalProperties': False,
+        # 'required': [],
     }
 
     # If not None, use find(FIND_PARAM=...) instead of get(...)
@@ -101,7 +101,7 @@ class GitLabracadabraObject(object):
     def _create(self, dry_run=False):
         obj_manager = self._object_manager()
         namespace_manager = self._gitlab_manager().namespaces
-        namespaces = self._name.split("/")
+        namespaces = self._name.split('/')
         object_path = namespaces.pop()
         create_params = {
             'path': object_path,
@@ -113,14 +113,17 @@ class GitLabracadabraObject(object):
                 create_params[param_name] = self._content[param_name]
         if len(namespaces):
             try:
-                parent_namespace = namespace_manager.get("/".join(namespaces))
+                parent_namespace = namespace_manager.get('/'.join(namespaces))
             except GitlabGetError as e:
                 error_message = e.error_message
                 if e.response_code == 404:
                     error_message = 'parent namespace not found'
                 logger.error('[%s] NOT Creating %s (%s)', self._name, self._type_name(), error_message)
                 return None
-            create_params['namespace_id'] = parent_namespace.id
+            if self._type_name() == 'group':
+                create_params['parent_id'] = parent_namespace.id
+            else:
+                create_params['namespace_id'] = parent_namespace.id
         if dry_run:
             logger.info('[%s] NOT Creating %s (dry-run)', self._name, self._type_name())
             return None
@@ -247,7 +250,7 @@ class GitLabracadabraObject(object):
                 if self._obj is None:
                     return
             else:
-                logger.info('[%s] NOT Creating %s (create_project is false)', self._name, self._type_name())
+                logger.info('[%s] NOT Creating %s (create_object is false)', self._name, self._type_name())
                 return
         for param_name, param_value in sorted(self._content.items()):
             process_method = getattr(self, '_process_' + param_name, self._process_param)
@@ -298,8 +301,7 @@ class GitLabracadabraObject(object):
             if doc[0] == '#':
                 matches = re.match(r'^(#+) ?(.*)$', doc)
                 indent = '  ' * (len(matches.group(1)) - 1)
-                output += indent + '- [' + doc.replace('#', '').strip() + \
-                          '](' + cls._markdown_link(doc) + ')\n'
+                output += indent + '- [' + doc.replace('#', '').strip() + '](' + cls._markdown_link(doc) + ')\n'
         output += '\n'
         # Detail
         for doc in cls.DOC:
@@ -308,11 +310,14 @@ class GitLabracadabraObject(object):
             elif doc in properties:
                 example = cls.EXAMPLE_YAML_HEADER
                 if '_example' in properties[doc]:
-                    example += '  ' + doc + ': ' + properties[doc]['_example'] + '\n'
+                    if properties[doc]['_example'].startswith('\n'):
+                        example += '  ' + doc + ':' + properties[doc]['_example'] + '\n'
+                    else:
+                        example += '  ' + doc + ': ' + properties[doc]['_example'] + '\n'
                 elif 'enum' in properties[doc]:
                     enum = properties[doc]['enum']
-                    example += '  ' + doc + ': ' + str(enum[0]) + \
-                               ' # one of ' + ', '.join([str(item) for item in enum]) + '\n'
+                    example += ('  ' + doc + ': ' + str(enum[0]) +
+                                ' # one of ' + ', '.join([str(item) for item in enum]) + '\n')
                 elif properties[doc]['type'] == 'boolean':
                     example += '  ' + doc + ': true # or false\n'
                 elif properties[doc]['type'] == 'integer':
@@ -321,8 +326,8 @@ class GitLabracadabraObject(object):
                     example += '  ' + doc + ': [My ' + doc.replace('_', ' ') + ']\n'
                 else:
                     example += '  ' + doc + ': My ' + doc.replace('_', ' ') + '\n'
-                output += '`' + doc + '` ' + properties[doc].get('description', 'Undocumented') + ':\n' \
-                          '```yaml\n' + example + '```\n\n'
+                output += '`' + doc + '` ' + properties[doc].get('description', 'Undocumented') + ':\n'
+                output += '```yaml\n' + example + '```\n\n'
             else:
                 output += '`' + doc + '` *Undocumented*.\n\n'
         return output
