@@ -59,124 +59,124 @@ class GitLabracadabraUser(GitLabracadabraObject):
         # 'user_note', # FIXME
     ]
     SCHEMA = {
-        "$schema": "http://json-schema.org/draft-04/schema#",
-        "title": "User",
-        "type": "object",
-        "properties": {
+        '$schema': 'http://json-schema.org/draft-04/schema#',
+        'title': 'User',
+        'type': 'object',
+        'properties': {
             # Standard properties
-            "create_object": {
-                "type": "boolean",
-                "description": "Create object if it does not exists",
+            'create_object': {
+                'type': 'boolean',
+                'description': 'Create object if it does not exists',
             },
-            "delete_object": {
-                "type": "boolean",
-                "description": "Delete object if it exists",
+            'delete_object': {
+                'type': 'boolean',
+                'description': 'Delete object if it exists',
             },
             # From https://docs.gitlab.com/ee/api/users.html#user-creation
-            "email": {
-                "type": "string",
-                "description": "Email",
+            'email': {
+                'type': 'string',
+                'description': 'Email',
             },
-            "password": {
-                "type": "string",
-                "description": "Password",
+            'password': {
+                'type': 'string',
+                'description': 'Password',
             },
-            "reset_password": {
-                "type": "boolean",
-                "description": "Send user password reset link",
+            'reset_password': {
+                'type': 'boolean',
+                'description': 'Send user password reset link',
             },
-            # "username": {
-            #     "type": "string",
-            #     "description": "Username",
+            # 'username': {
+            #     'type': 'string',
+            #     'description': 'Username',
             # },
-            "name": {
-                "type": "string",
-                "description": "Name",
+            'name': {
+                'type': 'string',
+                'description': 'Name',
             },
-            "skype": {
-                "type": "string",
-                "description": "Skype ID",
+            'skype': {
+                'type': 'string',
+                'description': 'Skype ID',
             },
-            "linkedin": {
-                "type": "string",
-                "description": "LinkedIn",
+            'linkedin': {
+                'type': 'string',
+                'description': 'LinkedIn',
             },
-            "twitter": {
-                "type": "string",
-                "description": "Twitter account",
+            'twitter': {
+                'type': 'string',
+                'description': 'Twitter account',
             },
-            "website_url": {
-                "type": "string",
-                "description": "Website URL",
+            'website_url': {
+                'type': 'string',
+                'description': 'Website URL',
             },
-            "organization": {
-                "type": "string",
-                "description": "Organization name",
+            'organization': {
+                'type': 'string',
+                'description': 'Organization name',
             },
-            "projects_limit": {
-                "type": "integer",
-                "description": "Number of projects user can create",
-                "multipleOf": 1,
-                "minimum": 0,
+            'projects_limit': {
+                'type': 'integer',
+                'description': 'Number of projects user can create',
+                'multipleOf': 1,
+                'minimum': 0,
             },
-            "extern_uid": {
-                "type": "string",
-                "description": "External UID",
+            'extern_uid': {
+                'type': 'string',
+                'description': 'External UID',
             },
-            "provider": {
-                "type": "string",
-                "description": "External provider name",
+            'provider': {
+                'type': 'string',
+                'description': 'External provider name',
             },
-            "bio": {
-                "type": "string",
-                "description": "User’s biography",
+            'bio': {
+                'type': 'string',
+                'description': 'User’s biography',
             },
-            "location": {
-                "type": "string",
-                "description": "User’s location",
+            'location': {
+                'type': 'string',
+                'description': 'User’s location',
             },
-            "public_email": {
-                "type": "string",
-                "description": "The public email of the user",
+            'public_email': {
+                'type': 'string',
+                'description': 'The public email of the user',
             },
-            "is_admin": {
-                "type": "boolean",
-                "description": "User is admin - true or false (default)",
+            'is_admin': {
+                'type': 'boolean',
+                'description': 'User is admin - true or false (default)',
             },
-            "can_create_group": {
-                "type": "boolean",
-                "description": "User can create groups - true or false",
+            'can_create_group': {
+                'type': 'boolean',
+                'description': 'User can create groups - true or false',
             },
-            "skip_confirmation": {
-                "type": "boolean",
-                "description": "Skip confirmation and assume e-mail is verified - true or false (default)",
+            'skip_confirmation': {
+                'type': 'boolean',
+                'description': 'Skip confirmation and assume e-mail is verified - true or false (default)',
             },
-            "external": {
-                "type": "boolean",
-                "description": "Flags the user as external - true or false(default)",
+            'external': {
+                'type': 'boolean',
+                'description': 'Flags the user as external - true or false(default)',
             },
-            "avatar": {
-                "type": "string",
-                "description": "Image file for user’s avatar",
+            'avatar': {
+                'type': 'string',
+                'description': 'Image file for user’s avatar',
             },
-            "private_profile": {
-                "type": "boolean",
-                "description": "User’s profile is private - true or false",
+            'private_profile': {
+                'type': 'boolean',
+                'description': 'User’s profile is private - true or false',
             },
-            "shared_runners_minutes_limit": {
-                "type": "integer",
-                "description": "Pipeline minutes quota for this user",
-                "multipleOf": 1,
-                "minimum": 0,
+            'shared_runners_minutes_limit': {
+                'type': 'integer',
+                'description': 'Pipeline minutes quota for this user',
+                'multipleOf': 1,
+                'minimum': 0,
             },
-            "extra_shared_runners_minutes_limit": {
-                "type": "integer",
-                "description": "Extra pipeline minutes quota for this user",
-                "multipleOf": 1,
-                "minimum": 0,
+            'extra_shared_runners_minutes_limit': {
+                'type': 'integer',
+                'description': 'Extra pipeline minutes quota for this user',
+                'multipleOf': 1,
+                'minimum': 0,
             },
         },
-        "additionalProperties": False,
+        'additionalProperties': False,
     }
 
     FIND_PARAM = 'username'
