@@ -25,7 +25,7 @@ from gitlabracadabra.utils import update_dict_with_defaults
 
 
 class GitlabracadabraParser(object):
-    """"YAML parser
+    """YAML parser
     """
     def __init__(self, action_file, config, recursion=0):
         self._action_file = action_file
@@ -57,7 +57,7 @@ class GitlabracadabraParser(object):
         with open(action_file) as yaml_blob:
             return cls.from_yaml(action_file, yaml_blob, recursion)
 
-    """"items()
+    """items()
 
     Handle hidden objects (starting with a dot) and extends.
     """
@@ -94,7 +94,7 @@ class GitlabracadabraParser(object):
             # Drop None values from v
             yield (k, {a: b for a, b in v.items() if b is not None})
 
-    """"_type_to_classname()
+    """_type_to_classname()
 
     Converts object-type to GitLabracadabraObjectType.
     """
@@ -104,7 +104,7 @@ class GitlabracadabraParser(object):
         mapped = map(lambda s: s[0].upper() + s[1:].lower(), splitted)
         return 'GitLabracadabra' + ''.join(mapped)
 
-    """"_type_to_module()
+    """_type_to_module()
 
     Converts object-type to gitlabracadabra.objects.object_type.
     """
@@ -112,7 +112,7 @@ class GitlabracadabraParser(object):
     def _type_to_module(cls, obj_type):
         return 'gitlabracadabra.objects.' + obj_type.lower().replace('-', '_')
 
-    """"get_class_for()
+    """get_class_for()
 
     Get the class for the given object type.
     """
@@ -122,7 +122,7 @@ class GitlabracadabraParser(object):
         obj_module = __import__(cls._type_to_module(obj_type), globals(), locals(), [obj_classname])
         return getattr(obj_module, obj_classname)
 
-    """"objects()
+    """objects()
 
     Returns .
     """
