@@ -173,4 +173,4 @@ class TestApplicationSettings(TestCase):
             'web_ide_clientside_preview_enabled': True,
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
