@@ -44,26 +44,26 @@ class TestGroup(TestCase):
     def test_no_create(self, cass):
         obj = GitLabracadabraGroup('memory', 'test/no_create_group', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_delete(self, cass):
         obj = GitLabracadabraGroup('memory', 'delete_this_group', {'delete_object': True})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_create(self, cass):
         obj = GitLabracadabraGroup('memory', 'test/create_group', {'create_object': True})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_missing_parent(self, cass):
         obj = GitLabracadabraGroup('memory', 'test/missing_parent/subgroup', {'create_object': True})
         with patch('gitlabracadabra.objects.object.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.error.assert_called_once_with('[%s] NOT Creating %s (%s)',
                                                  'test/missing_parent/subgroup',
                                                  'group',
@@ -73,7 +73,7 @@ class TestGroup(TestCase):
     def test_exists(self, cass):
         obj = GitLabracadabraGroup('memory', 'test/group_exists', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_simple_parameters(self, cass):
@@ -90,7 +90,7 @@ class TestGroup(TestCase):
             # 'extra_shared_runners_minutes_limit': 42,  # EE, admin-only
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members(self, cass):
@@ -98,7 +98,7 @@ class TestGroup(TestCase):
             'members': {'some_member': 'developer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members_change_access_level(self, cass):
@@ -106,7 +106,7 @@ class TestGroup(TestCase):
             'members': {'some_member': 'maintainer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members_not_found(self, cass):
@@ -119,7 +119,7 @@ class TestGroup(TestCase):
         })
         with patch('gitlabracadabra.mixins.members.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] User not found %s',
                                                    'test/group_members', 'member_not_found')
 
@@ -130,7 +130,7 @@ class TestGroup(TestCase):
             'unknown_members': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     # https://github.com/python-gitlab/python-gitlab/pull/1139
     @skipIf(gitlab_version in ['1.6.0', '2.4.0'], 'python-gitlab without share group with groups')
@@ -140,7 +140,7 @@ class TestGroup(TestCase):
             'groups': {'test/group1': 'developer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     # https://github.com/python-gitlab/python-gitlab/pull/1139
     @skipIf(gitlab_version in ['1.6.0', '2.4.0'], 'python-gitlab without share group with groups')
@@ -150,7 +150,7 @@ class TestGroup(TestCase):
             'groups': {'test/group1': 'maintainer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     # https://github.com/python-gitlab/python-gitlab/pull/1139
     @skipIf(gitlab_version in ['1.6.0', '2.4.0'], 'python-gitlab without share group with groups')
@@ -162,7 +162,7 @@ class TestGroup(TestCase):
         })
         with patch('gitlabracadabra.mixins.groups.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] Group not found %s',
                                                            'test/group_of_groups3',
                                                            'test/group_not_found')
@@ -176,7 +176,7 @@ class TestGroup(TestCase):
             'unknown_groups': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_variables(self, cass):
@@ -202,7 +202,7 @@ class TestGroup(TestCase):
             'unknown_variables': 'ignore',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     # https://github.com/python-gitlab/python-gitlab/pull/847
     @skipIf(gitlab_version in ['1.6.0', '1.10.0', '1.11.0', '1.13.0'], 'python-gitlab without group labels support')
@@ -223,7 +223,7 @@ class TestGroup(TestCase):
             'unknown_labels': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_milestones(self, cass):
@@ -247,4 +247,4 @@ class TestGroup(TestCase):
             'unknown_milestones': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
