@@ -27,10 +27,10 @@ from gitlabracadabra.tests.utils import patch_open
 class TestParser(TestCase):
     def test_from_yaml_file(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 message:
                   hello: world
-                '''
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -39,14 +39,14 @@ class TestParser(TestCase):
 
     def test_include_str(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 include:
                   - included.yml
-                ''',
-            'included.yml': '''
+                """,
+            'included.yml': """
                 message:
                   hello: world
-                '''
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -55,14 +55,14 @@ class TestParser(TestCase):
 
     def test_include_local(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 include:
                   - local: included.yml
-                ''',
-            'included.yml': '''
+                """,
+            'included.yml': """
                 message:
                   hello: world
-                '''
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -71,14 +71,14 @@ class TestParser(TestCase):
 
     def test_include_recursion(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 include:
                   - included.yml
-                ''',
-            'included.yml': '''
+                """,
+            'included.yml': """
                 include:
                   - gitlabracadabra.yml
-                '''
+                """,
         }
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
@@ -89,10 +89,10 @@ class TestParser(TestCase):
 
     def test_include_forbidden_relative_path(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 include:
                   - ../included.yml
-                '''
+                """,
         }
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
@@ -103,10 +103,10 @@ class TestParser(TestCase):
 
     def test_include_forbidden_absolute_path(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 include:
                   - /included.yml
-                '''
+                """,
         }
         with patch_open(contents_map):
             with self.assertRaises(ValueError) as cm:
@@ -116,7 +116,7 @@ class TestParser(TestCase):
         self.assertEqual(str(cm.exception), 'gitlabracadabra.yml: forbidden path for `include`: /included.yml')
 
     def test_extend(self):
-        p = GitlabracadabraParser.from_yaml('-', '''
+        p = GitlabracadabraParser.from_yaml('-', """
             .hidden-key:
               param1: value1
               param2: value2
@@ -125,7 +125,7 @@ class TestParser(TestCase):
               param3: value3
             another-key:
               param4: value4
-            ''')
+            """)
         d = {k: v for k, v in p._items()}
 
         self.assertNotIn('.hidden-key', d)
@@ -134,7 +134,7 @@ class TestParser(TestCase):
         self.assertEqual(d['another-key'], {'param4': 'value4'})
 
     def test_extend_recursion(self):
-        p = GitlabracadabraParser.from_yaml('-', '''
+        p = GitlabracadabraParser.from_yaml('-', """
             key1:
               extends: key3
               foo: bar
@@ -144,20 +144,20 @@ class TestParser(TestCase):
             key3:
               extends: key2
               foo3: bar3
-            ''')
+            """)
         with self.assertRaises(ValueError) as cm:
             {k: v for k, v in p._items()}
 
         self.assertEqual(str(cm.exception), '- (key1): nesting too deep in `extends`')
 
     def test_extend_unknown_merge_strategy(self):
-        p = GitlabracadabraParser.from_yaml('-', '''
+        p = GitlabracadabraParser.from_yaml('-', """
             key1:
               hello: world
             key2:
               extends:
                 - key1: keep-the-best
-            ''')
+            """)
         with self.assertRaises(ValueError) as cm:
             {k: v for k, v in p._items()}
 
@@ -165,7 +165,7 @@ class TestParser(TestCase):
 
     def test_include_and_extend(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 group1/project1:
                   name: foo
                   extends: .e1
@@ -181,8 +181,8 @@ class TestParser(TestCase):
 
                 include:
                   - local: included.yml
-                ''',
-            'included.yml': '''
+                """,
+            'included.yml': """
                 .e1:
                   branches:
                     - master
@@ -190,7 +190,7 @@ class TestParser(TestCase):
                     - staging
                   members:
                     foo: developer
-                '''
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -206,7 +206,7 @@ class TestParser(TestCase):
 
     def test_extend_list(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 group1/project1:
                   name: foo
                   extends:
@@ -236,7 +236,7 @@ class TestParser(TestCase):
                     - develop3
                   members:
                     bar: developer # override .e1 maintainer
-                ''',
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -252,7 +252,7 @@ class TestParser(TestCase):
 
     def test_extend_list_aggregate(self):
         contents_map = {
-            'gitlabracadabra.yml': '''
+            'gitlabracadabra.yml': """
                 group1/project1:
                   name: foo
                   extends:
@@ -282,7 +282,7 @@ class TestParser(TestCase):
                     - develop3
                   members:
                     bar: developer # override .e1 maintainer
-                ''',
+                """,
         }
         with patch_open(contents_map):
             p = GitlabracadabraParser.from_yaml_file('gitlabracadabra.yml')
@@ -297,7 +297,7 @@ class TestParser(TestCase):
         })
 
     def test_objects(self):
-        p = GitlabracadabraParser.from_yaml('-', '''
+        p = GitlabracadabraParser.from_yaml('-', """
             .project-template:
               wiki_enabled: true
               issues_enabled: true
@@ -308,7 +308,7 @@ class TestParser(TestCase):
               wiki_enabled: false
               description: My project
               buggy_param: Oh no!
-            ''')
+            """)
         d = p.objects()
 
         self.assertNotIn('.project-template', d)
@@ -323,7 +323,7 @@ class TestParser(TestCase):
         project1 = d['group1/project1']
         self.assertIsInstance(project1, GitLabracadabraProject)
         self.assertEqual(len(project1._errors), 1)
-        self.assertEqual(project1._errors[0].message, "Additional properties are not allowed "
+        self.assertEqual(project1._errors[0].message, 'Additional properties are not allowed '
                                                       "('buggy_param' was unexpected)")
         self.assertEqual(project1._content, {'buggy_param': 'Oh no!',
                                              'description': 'My project',
