@@ -44,25 +44,25 @@ class TestProject(TestCase):
     def test_no_create(self, cass):
         obj = GitLabracadabraProject('memory', 'test/no_create_object', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_create(self, cass):
         obj = GitLabracadabraProject('memory', 'test/create_object', {'create_object': True})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_delete(self, cass):
         obj = GitLabracadabraProject('memory', 'test/delete_me', {'delete_object': True})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_exists(self, cass):
         obj = GitLabracadabraProject('memory', 'test/exists', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_simple_parameters(self, cass):
@@ -101,7 +101,7 @@ class TestProject(TestCase):
             # 'packages_enabled': True,  # EE
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_simple_parameters2(self, cass):
@@ -121,7 +121,7 @@ class TestProject(TestCase):
             'auto_devops_deploy_strategy': 'timed_incremental',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_default_branch_exists(self, cass):
@@ -129,7 +129,7 @@ class TestProject(TestCase):
             'default_branch': 'exists',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_default_branch_not_exists(self, cass):
@@ -138,7 +138,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.object.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.error.assert_called_once_with('[%s] Unable to change param %s (%s -> %s): %s',
                                                  'test/project_default_branch',
                                                  'default_branch',
@@ -154,7 +154,7 @@ class TestProject(TestCase):
 
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_groups(self, cass):
@@ -162,7 +162,7 @@ class TestProject(TestCase):
             'groups': {'test2': 'developer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_groups_change_access_level(self, cass):
@@ -170,7 +170,7 @@ class TestProject(TestCase):
             'groups': {'test2': 'maintainer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_groups_not_found(self, cass):
@@ -180,7 +180,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.mixins.groups.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] Group not found %s',
                                                            'test/project_groups',
                                                            'group_not_found')
@@ -192,7 +192,7 @@ class TestProject(TestCase):
             'unknown_groups': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members(self, cass):
@@ -203,7 +203,7 @@ class TestProject(TestCase):
             'members': {'some_member': 'developer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members_change_access_level(self, cass):
@@ -211,7 +211,7 @@ class TestProject(TestCase):
             'members': {'some_member': 'maintainer'},
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_members_not_found(self, cass):
@@ -224,7 +224,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.mixins.members.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] User not found %s',
                                                    'test/project_members', 'member_not_found')
 
@@ -235,7 +235,7 @@ class TestProject(TestCase):
             'unknown_members': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_protected_branches_wildcard(self, cass):
@@ -244,7 +244,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.warning.assert_called_once_with('[%s] NOT Deleting unknown protected branch: %s'
                                                    ' (unknown_protected_branches=%s)',
                                                    'test/protected_branches', 'master', 'warn')
@@ -257,7 +257,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Deleting unknown protected branch: %s',
                                                    'test/protected_branches', 'master')
 
@@ -269,7 +269,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing protected tag %s access level: %s -> %s',
                                                 'test/protected_tags', 'v*',
                                                 {}, {'name': 'v*', 'create_access_level': 40})
@@ -282,7 +282,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing protected tag %s access level: %s -> %s',
                                                 'test/protected_tags', 'v1.0',
                                                 {'name': 'v1.0', 'create_access_level': 30},
@@ -297,7 +297,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Deleting unknown protected tag: %s',
                                                    'test/protected_tags', 'unknown')
 
@@ -308,7 +308,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing param %s: %s -> %s',
                                                    'test/archived', 'archived', False, True)
 
@@ -319,7 +319,7 @@ class TestProject(TestCase):
         })
         with patch('gitlabracadabra.objects.project.logger', autospec=True) as logger:
             obj.process()
-            self.assertEqual(cass.all_played, True)
+            self.assertTrue(cass.all_played)
             logger.info.assert_called_once_with('[%s] Changing param %s: %s -> %s',
                                                    'test/unarchived', 'archived', True, False)
 
@@ -347,7 +347,7 @@ class TestProject(TestCase):
             'unknown_variables': 'ignore',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @skipIf(gitlab_version in ['1.11.0', '1.13.0'], 'python-gitlab without proper project labels support')
     @my_vcr.use_cassette
@@ -367,7 +367,7 @@ class TestProject(TestCase):
             'unknown_labels': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_milestones(self, cass):
@@ -391,96 +391,111 @@ class TestProject(TestCase):
             'unknown_milestones': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_webhooks(self, cass):
         obj = GitLabracadabraProject('memory', 'test/test_webhooks', {
             'webhooks': [
                 {
-                    "url": "http://example.com/create_me",
-                    "push_events": False,
-                    "push_events_branch_filter": "master",
-                    "issues_events": True,
-                    "confidential_issues_events": True,
-                    "merge_requests_events": True,
-                    "tag_push_events": True,
-                    "note_events": True,
-                    "confidential_note_events": True,
-                    "job_events": True,
-                    "pipeline_events": True,
-                    "wiki_page_events": True,
-                    "enable_ssl_verification": False,
-                    # "repository_update_events": True,
+                    'url': 'http://example.com/create_me',
+                    'push_events': False,
+                    'push_events_branch_filter': 'master',
+                    'issues_events': True,
+                    'confidential_issues_events': True,
+                    'merge_requests_events': True,
+                    'tag_push_events': True,
+                    'note_events': True,
+                    'confidential_note_events': True,
+                    'job_events': True,
+                    'pipeline_events': True,
+                    'wiki_page_events': True,
+                    'enable_ssl_verification': False,
+                    # 'repository_update_events': True,
                 },
                 {
-                    "url": "http://example.com/modify_me",
-                    "push_events": False,
-                    "push_events_branch_filter": "master",
-                    "issues_events": True,
-                    "confidential_issues_events": True,
-                    "merge_requests_events": True,
-                    "tag_push_events": True,
-                    "note_events": True,
-                    "confidential_note_events": True,
-                    "job_events": True,
-                    "pipeline_events": True,
-                    "wiki_page_events": True,
-                    "enable_ssl_verification": False,
-                    # "repository_update_events": True,
+                    'url': 'http://example.com/modify_me',
+                    'push_events': False,
+                    'push_events_branch_filter': 'master',
+                    'issues_events': True,
+                    'confidential_issues_events': True,
+                    'merge_requests_events': True,
+                    'tag_push_events': True,
+                    'note_events': True,
+                    'confidential_note_events': True,
+                    'job_events': True,
+                    'pipeline_events': True,
+                    'wiki_page_events': True,
+                    'enable_ssl_verification': False,
+                    # 'repository_update_events': True,
                 },
             ],
             'unknown_webhooks': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
+
+    @my_vcr.use_cassette
+    def test_container_expiration_policy(self, cass):
+        obj = GitLabracadabraProject('memory', 'test/container_expiration_policy', {
+            'container_expiration_policy': {
+                'enabled': True,
+                'cadence': '14d',
+                'keep_n': 25,
+                'name_regex_keep': '.*master|.*release|release-.*|master-.*',
+                'older_than': '90d',
+                'name_regex_delete': '.*',
+            },
+        })
+        obj.process()
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_pipeline_schedules(self, cass):
         obj = GitLabracadabraProject('memory', 'test/test_pipeline_schedules', {
             'pipeline_schedules': [
                 {
-                    "description": "create_me",
-                    "ref": "master",
-                    "cron": "0 1 * * 5",
-                    "cron_timezone": "UTC",
-                    "active": True,
+                    'description': 'create_me',
+                    'ref': 'master',
+                    'cron': '0 1 * * 5',
+                    'cron_timezone': 'UTC',
+                    'active': True,
                 },
                 {
-                    "description": "modify_me",
-                    "ref": "develop",
-                    "cron": "0 3 * * 5",
-                    "cron_timezone": "Pacific Time (US & Canada)",
-                    "active": False,
+                    'description': 'modify_me',
+                    'ref': 'develop',
+                    'cron': '0 3 * * 5',
+                    'cron_timezone': 'Pacific Time (US & Canada)',
+                    'active': False,
                 },
             ],
             'unknown_pipeline_schedules': 'delete',
             'unknown_pipeline_schedule_variables': 'ignore',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_pipeline_schedule_variables(self, cass):
         obj = GitLabracadabraProject('memory', 'test/test_pipeline_schedule_variables', {
             'pipeline_schedules': [
                 {
-                    "description": "some_schedule",
-                    "ref": "master",
-                    "cron": "0 16 * * *",
-                    "cron_timezone": "UTC",
-                    "active": False,
-                    "variables": [
+                    'description': 'some_schedule',
+                    'ref': 'master',
+                    'cron': '0 16 * * *',
+                    'cron_timezone': 'UTC',
+                    'active': False,
+                    'variables': [
                         {
-                            "key": "create_me",
-                            "value": "some_value",
-                            "variable_type": "file",
+                            'key': 'create_me',
+                            'value': 'some_value',
+                            'variable_type': 'file',
                         },
                         {
-                            "key": "modify_me",
-                            "value": "new_value",
-                            "variable_type": "file",
-                        }
+                            'key': 'modify_me',
+                            'value': 'new_value',
+                            'variable_type': 'file',
+                        },
                     ],
                 },
             ],
@@ -488,4 +503,4 @@ class TestProject(TestCase):
             'unknown_pipeline_schedule_variables': 'delete',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
