@@ -39,7 +39,7 @@ class TestUser(TestCase):
     def test_no_create(self, cass):
         obj = GitLabracadabraUser('memory', 'no_create_user', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_create(self, cass):
@@ -50,19 +50,19 @@ class TestUser(TestCase):
             'password': 'P@ssw0rdNot24get',
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_delete(self, cass):
         obj = GitLabracadabraUser('memory', 'delete_this_user', {'delete_object': True})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_exists(self, cass):
         obj = GitLabracadabraUser('memory', 'user_exists', {})
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def notest_simple_parameters(self, cass):
@@ -75,7 +75,7 @@ class TestUser(TestCase):
             # 'shared_runners_minutes_limit': 42,  # EE, admin-only
         })
         obj.process()
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_get_id_from_username(self, cass):
@@ -84,7 +84,7 @@ class TestUser(TestCase):
         GitLabracadabraUser._USERS_ID2USERNAME = {}
         ret = GitLabracadabraUser.get_id_from_username('user_mapping')
         self.assertEqual(ret, 9)
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
 
     @my_vcr.use_cassette
     def test_get_username_from_id(self, cass):
@@ -93,4 +93,4 @@ class TestUser(TestCase):
         GitLabracadabraUser._USERS_ID2USERNAME = {}
         ret = GitLabracadabraUser.get_username_from_id(9)
         self.assertEqual(ret, 'user_mapping')
-        self.assertEqual(cass.all_played, True)
+        self.assertTrue(cass.all_played)
